@@ -34,11 +34,14 @@ int _listdirs(struct node_t *dir, void *dirs, void *ancestors)
 		if (strcmp(namelist[i]->d_name,"..")==0)
 			continue;
 		asprintf(&d,"%s/%s",dir->filename,namelist[i]->d_name);
-		node_new(&newdir,d);
+		retval = node_new(&newdir,d);
 		free(d);d=NULL;
-		if (S_ISDIR(newdir.statbuf.st_mode))
-			retval = _listdirs(&newdir,dirs,ancestors);
-		node_free(&newdir);
+		if (retval == 0)
+		{
+			if (S_ISDIR(newdir.statbuf.st_mode))
+				retval = _listdirs(&newdir,dirs,ancestors);
+			node_free(&newdir);
+		}
 		free(namelist[i]);
 	}
 	free(namelist);
