@@ -14,6 +14,13 @@ char *xrealpath(char *filepath)
       if (errno == ENOENT)
       {
          fprintf(stderr,"Error: file '%s' not found.\n",filepath);
+	 free(buffer);
+         return NULL;
+      }
+      else if (errno == ELOOP)
+      {
+         fprintf(stderr,"Error: file '%s' is a faulty symbolic link.\n",filepath);
+	 free(buffer);
          return NULL;
       }
       perror("realpath");
